@@ -3,8 +3,8 @@ import re
 import sys
 
 from inline_snapshot import snapshot
+from inline_snapshot.extra import transformation
 from inline_snapshot.testing import Example
-from tests._is_normalized import normalization
 
 executable = sys.executable.replace("\\", "\\\\")
 
@@ -108,7 +108,7 @@ def test_a():
 
 def test_format_command_fail():
 
-    @normalization
+    @transformation
     def NoPaths(text):
         path_re = "/[^ ]*/" if platform.system() != "Windows" else r".:\\[^ ]*\\"
         text = re.sub(
@@ -254,3 +254,31 @@ def test_a():
         ),
         returncode=1,
     )
+
+
+def test_black_does_not_trim_spaces():
+    # https://github.com/15r10nk/inline-snapshot/issues/301
+
+    Example(
+        {
+            "test_a.py": """\
+from inline_snapshot import snapshot
+
+def test_a():
+    assert " a " == snapshot("")
+""",
+        }
+    ).run_pytest(
+        ["--inline-snapshot=fix"],
+        changed_files=snapshot(
+            {
+                "test_a.py": """\
+from inline_snapshot import snapshot
+
+def test_a():
+    assert " a " == snapshot(" a ")
+"""
+            }
+        ),
+        returncode=1,
+    ).run_inline()
